==> scilab-2.1.1.tar.gz: scilab-2.1.1/routines/xsci/help/help-text3.h <==
"  abs   -  absolute value, magnitude ",
"  acos   - cosine inverse ",
"  acosh   - hyperbolic cosine inverse ",
"  addf   - symbolic addition ",
"  amell   - Jacobi's am function ",
"  asin   -  sine inverse ",
"  asinh   - hyperbolic sine inverse ",
"  atan   - tangent inverse ",
"  atanh   - hyperbolic tangent inverse ",
"  bloc2exp   - block-diagram to symbolic expression ",
"  bloc2ss   - block-diagram to state-space conversion ",
"  c_link   - check dynamic link ",
"  calerf   -  computes error functions. ",
"  cmb_lin   - symbolic linear combination ",
"  conj   -  conjugate ",
"  convstr   - case conversion ",
"  cos   -  cosine function ",
"  cosh   - hyperbolic cosine ",
"  cotg   - cotangent ",
"  coth   - hyperbolic cotangent ",
"  debug   - debugging level ",
"  delip   - elliptic integral ",
"  demos   -  guide for scilab demos ",
"  diag   - diagonal including or extracting  ",
"  edit   -  function editing ",
"  emptystr   - zero length string ",
"  erf   -  The error function. ",
"  erfc   -  The complementary error function. ",
"  erfcx   -  The scaled complementary error function. ",
"  eval   - evaluation of a matrix of strings ",
"  execstr   - command execution by evaluation of strings ",
"  full   -  sparse to full matrix conversion ",
"  getvalue   - xwindow dialog for data acquisition  ",
"  halt   - stop execution ",
"  havewindow   - return scilab window mode ",
"  input   - prompt for user input ",
"  integrate   - integration by quadrature ",
"  interp   - interpolation ",
"  interpln   - linear interpolation ",
"  isdef   - check variable  existence ",
"  kron   - Kronecker product ",
"  ldivf   - left symbolic division ",
"  linspace   - linearly spaced vector ",
"  log   - logarithm ",
"  logspace   - logarithmically spaced vector ",
"  mac2for   - function to fortran routine conversion ",
"  macr2lst   - function to list conversion ",
"  macrovar   - variables of function ",
"  manedit   -  editing a manual item ",
"  modulo   - arithmetic remainder modulo m ",
"  mulf   -  symbolic multiplication ",
"  norm   - matrix norms ",
"  pen2ea   - pencil to E,A conversion ",
"  pertrans   - pertranspose ",
"  pol2tex   - convert polynomial  to TeX format ",
"  prod   - product ",
"  rdivf   - right symbolic division ",
"  readc_   - read a character string ",
"  sci2exp   - converts  variable to an expression ",
"  sci2map   - Scilab to Maple ",
"  sin   -  sine function ",
"  sinh   - hyperbolic sine ",
"  smooth   - smoothing by spline functions ",
"  solve   - symbolic linear system solver ",
"  sort   - decreasing order sorting ",
"  sparse   -  sparse matrix definition ",
"  speye   -  sparse identity matrix ",
"  spget   - retrieves entries of sparse matrix ",
"  splin   - spline function ",
"  sprand   -  sparse random matrix ",
"  spzeros   -  sparse zero matrix ",
"  sqrt   - square root ",
"  ssprint   - pretty print for linear system ",
"  ssrand   - random system generator ",
"  strcat   - catenate character strings ",
"  subf   -  symbolic subtraction ",
"  sum   - sum  of vector/matrix entries ",
"  sysconv   - system conversion ",
"  sysdiag   - block diagonal system connection ",
"  syslin   - linear system definition ",
"  tan   - tangent ",
"  tanh   - hyperbolic tangent ",
"  texprint   - TeX output of Scilab object ",
"  timer   - cpu time ",
"  toeplitz   - toeplitz matrix ",
"  trfmod   - poles and zeros display ",
"  trianfml   - symbolic triangularization ",
"  tril   - lower triangular part of matrix ",
"  trisolve   - symbolic linear system solver ",
"  triu   - upper triangle ",
"  typeof   -  object type ",
"  x_choose   - interactive Xwindow choice ",
"  x_dialog   - Xwindow dialog ",
"  x_matrix   - Xwindow editing of matrix  ",
"  x_mdialog   - Xwindow dialog ",
"  x_message   - X window message ",
"  zeros   - matrix made of zeros ",

==> scilab_2.2.orig.tar.gz: scilab-2.2.orig/routines/xsci/help/help-text3.h <==
"  abs   -  absolute value, magnitude ",
"  acos   - cosine inverse ",
"  acosh   - hyperbolic cosine inverse ",
"  addf   - symbolic addition ",
"  addmenu   - interactive button or menu definition ",
"  amell   - Jacobi's am function ",
"  asin   -  sine inverse ",
"  asinh   - hyperbolic sine inverse ",
"  atan   - tangent inverse ",
"  atanh   - hyperbolic tangent inverse ",
"  bloc2exp   - block-diagram to symbolic expression ",
"  bloc2ss   - block-diagram to state-space conversion ",
"  c_link   - check dynamic link ",
"  calerf   -  computes error functions. ",
"  cmb_lin   - symbolic linear combination ",
"  conj   -  conjugate ",
"  convstr   - case conversion ",
"  cos   -  cosine function ",
"  cosh   - hyperbolic cosine ",
"  cotg   - cotangent ",
"  coth   - hyperbolic cotangent ",
"  debug   - debugging level ",
"  delip   - elliptic integral ",
"  delmenu   - interactive button or menu deletion ",
"  demos   -  guide for scilab demos ",
"  diag   - diagonal including or extracting  ",
"  edit   -  function editing ",
"  emptystr   - zero length string ",
"  erf   -  The error function. ",
"  erfc   -  The complementary error function. ",
"  erfcx   -  The scaled complementary error function. ",
"  eval   - evaluation of a matrix of strings ",
"  execstr   - command execution by evaluation of strings ",
"  full   -  sparse to full matrix conversion ",
"  getvalue   - xwindow dialog for data acquisition  ",
"  halt   - stop execution ",
"  havewindow   - return scilab window mode ",
"  input   - prompt for user input ",
"  integrate   - integration by quadrature ",
"  interp   - interpolation ",
"  interpln   - linear interpolation ",
"  isdef   - check variable  existence ",
"  kron   - Kronecker product ",
"  ldivf   - left symbolic division ",
"  linspace   - linearly spaced vector ",
"  log   - logarithm ",
"  log   - logarithm ",
"  logspace   - logarithmically spaced vector ",
"  mac2for   - function to fortran routine conversion ",
"  macr2lst   - function to list conversion ",
"  macrovar   - variables of function ",
"  manedit   -  editing a manual item ",
"  modulo   - arithmetic remainder modulo m ",
"  mulf   -  symbolic multiplication ",
"  norm   - matrix norms ",
"  pen2ea   - pencil to E,A conversion ",
"  pertrans   - pertranspose ",
"  pol2tex   - convert polynomial  to TeX format ",
"  prod   - product ",
"  rdivf   - right symbolic division ",
"  readc_   - read a character string ",
"  sci2exp   - converts  variable to a scilab expression ",
"  sci2map   - Scilab to Maple ",
"  setmenu   - interactive button or menu activation ",
"  sin   -  sine function ",
"  sinh   - hyperbolic sine ",
"  smooth   - smoothing by spline functions ",
"  solve   - symbolic linear system solver ",
"  sort   - decreasing order sorting ",
"  sparse   -  sparse matrix definition ",
"  speye   -  sparse identity matrix ",
"  spget   - retrieves entries of sparse matrix ",
"  splin   - spline function ",
"  sprand   -  sparse random matrix ",
"  spzeros   -  sparse zero matrix ",
"  sqrt   - square root ",
"  ssprint   - pretty print for linear system ",
"  ssrand   - random system generator ",
"  strcat   - catenate character strings ",
"  subf   -  symbolic subtraction ",
"  sum   - sum  of vector/matrix entries ",
"  sysconv   - system conversion ",
"  sysdiag   - block diagonal system connection ",
"  syslin   - linear system definition ",
"  tan   - tangent ",
"  tanh   - hyperbolic tangent ",
"  texprint   - TeX output of Scilab object ",
"  timer   - cpu time ",
"  toeplitz   - toeplitz matrix ",
"  trfmod   - poles and zeros display ",
"  trianfml   - symbolic triangularization ",
"  tril   - lower triangular part of matrix ",
"  trisolve   - symbolic linear system solver ",
"  triu   - upper triangle ",
"  typeof   -  object type ",
"  unsetmenu   - interactive button or menu or submenu de-activation ",
"  x_choices   - interactive Xwindow choices through toggle buttons ",
"  x_choose   - interactive Xwindow choice ",
"  x_dialog   - Xwindow dialog ",
"  x_matrix   - Xwindow editing of matrix  ",
"  x_mdialog   - Xwindow dialog ",
"  x_message   - X window message ",
"  xgetfile   - dialog to get a file path ",
"  zeros   - matrix made of zeros ",
